@@ -19,7 +19,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/cif/CIFrdutils.c,v 1.3 2010/05/21 22:15:11 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/cif/CIFrdutils.c,v 1.4 2010/06/24 12:37:15 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -76,7 +76,6 @@ bool CIFRescaleAllow = TRUE;		/* Don't subdivide the magic internal
 					 */
 char *CIFErrorFilename;			/* Name of file for error redirection */
 
-#ifdef NONMANHATTAN
 int  CifPolygonCount;			/* Count of generated subcells
 					 * containing polygons.  This number
 					 * is used to create a unique cell name.
@@ -85,7 +84,6 @@ bool CIFSubcellPolygons = FALSE;	/* If TRUE, each non-Manhattan polygon
 					 * will be put in a separate subcell
 					 * to avoid too much tile splitting
 					 */
-#endif
 
 Plane *cifReadPlane;			/* Plane into which to paint material
 					 * NULL means no layer command has
@@ -688,10 +686,6 @@ CIFParsePath(pathheadpp, iscale)
 	    if (pathtailp->cifp_x != newpathp->cifp_x
 		    && pathtailp->cifp_y != (newpathp->cifp_y))
 	    {
-#ifndef NONMANHATTAN
-		if (!nonManhattan)
-		    CIFReadWarning("non-Manhattan path; using stairstep.\n");
-#endif
 		nonManhattan = TRUE;
 	    }
 	    pathtailp->cifp_next = newpathp;
@@ -702,8 +696,6 @@ CIFParsePath(pathheadpp, iscale)
     return (*pathheadpp != NULL);
 }
 
-#ifdef NONMANHATTAN
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1133,161 +1125,6 @@ CIFMakeManhattanPath(pathHead, plane, resultTbl, ui)
     }
 }
 
-#else
-
-
-/*
- * ----------------------------------------------------------------------------
- *
- * CIFMakeManhattanPath --
- *
- *	Convert a non-Manhattan path into a Manhattan one by adding
- *	additional points.  These points are added using a simple
- *	scan-conversion algorithm that generates a series of stair
- *	steps that are at least cifCurReadStyle->crs_scaleFactor
- *	units high and wide (but which may be higher or wider).
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	May insert additional points in the path.
- *
- * ----------------------------------------------------------------------------
- */
-
-void
-CIFMakeManhattanPath(pathHead)
-    CIFPath *pathHead;
-{
-    CIFPath *new, *next, *path;
-    int xinit, xdiff, xincr, xlast, x;
-    int yinit, ydiff, yincr, ylast, y;
-
-    for (path = pathHead; path->cifp_next; path = path->cifp_next)
-    {
-	next = path->cifp_next;
-
-	/* No work if this segment is Manhattan */
-	if (path->cifp_x == next->cifp_x || path->cifp_y == next->cifp_y)
-	    continue;
-
-	/*
-	 * The major loop will be over whichever difference (x or y)
-	 * is the SMALLER of the two; for each iteration over the smaller
-	 * dimension, we will add the number of units of the larger
-	 * dimension per unit of the smaller dimension to the larger
-	 * dimension.
-	 */
-	xdiff = next->cifp_x - path->cifp_x;
-	ydiff = next->cifp_y - path->cifp_y;
-	xinit = path->cifp_x;
-	yinit = path->cifp_y;
-	if (ABS(xdiff) > ABS(ydiff))
-	{
-	    /* Iterate over y, stopping before next->cifp_y */
-	    yincr = cifCurReadStyle->crs_scaleFactor;
-	    ylast = yinit;
-	    if (ydiff < 0) yincr = -yincr;
-	    for (y = yinit + yincr, x = xinit;
-			(yincr > 0 && y < next->cifp_y)
-		     || (yincr < 0 && y > next->cifp_y);
-		    y += yincr)
-	    {
-		/* Move by one in y first */
-		new = (CIFPath *) mallocMagic((unsigned) (sizeof (CIFPath)));
-		new->cifp_x = x;
-		new->cifp_y = y;
-		path->cifp_next = new;
-		path = new;
-
-		/*
-		 * Now move in x.
-		 * Note that ((y - yinit) / ydiff) >= 0 always.
-		 * Also, as long as y has not reached next->cifp_y,
-		 * this quantity will be < 1, so x will range from
-		 * path->cifp_x up to but not reaching next->cifp_x.
-		 */
-		x = xinit + (xdiff * (y - yinit)) / ydiff;
-		new = (CIFPath *) mallocMagic ((unsigned) (sizeof (CIFPath)));
-		new->cifp_x = x;
-		new->cifp_y = y;
-		new->cifp_next = next;
-		path->cifp_next = new;
-		path = new;
-		ylast = y;
-	    }
-
-	    /*
-	     * The last y processed was short of next->cifp_y.
-	     * If x was not yet at next->cifp_x, add one more point
-	     * to bridge the gap.
-	     */
-	    if (x != next->cifp_x)
-	    {
-		new = (CIFPath *) mallocMagic((unsigned) (sizeof (CIFPath)));
-		new->cifp_x = next->cifp_x;
-		new->cifp_y = ylast;;
-		new->cifp_next = next;
-		path->cifp_next = new;
-		path = new;
-	    }
-	}
-	else
-	{
-	    /* Iterate over x, stopping before next->cifp_x */
-	    xincr = cifCurReadStyle->crs_scaleFactor;
-	    xlast = xinit;
-	    if (xdiff < 0) xincr = -xincr;
-	    for (x = xinit + xincr, y = yinit;
-			(xincr > 0 && x < next->cifp_x)
-		     || (xincr < 0 && x > next->cifp_x);
-		x += xincr)
-	    {
-		/* Move by one in x first */
-		new = (CIFPath *) mallocMagic((unsigned) (sizeof (CIFPath)));
-		new->cifp_x = x;
-		new->cifp_y = y;
-		path->cifp_next = new;
-		path = new;
-
-		/*
-		 * Now move in y.
-		 * Note that ((x - xinit) / xdiff) >= 0 always.
-		 * Also, as long as x has not reached next->cifp_x,
-		 * this quantity will be < 1, so y will range from
-		 * path->cifp_y up to but not reaching next->cifp_y.
-		 */
-		y = yinit + (ydiff * (x - xinit)) / xdiff;
-		new = (CIFPath *) mallocMagic((unsigned) (sizeof (CIFPath)));
-		new->cifp_x = x;
-		new->cifp_y = y;
-		new->cifp_next = next;
-		path->cifp_next = new;
-		path = new;
-		xlast = x;
-	    }
-
-	    /*
-	     * The last x processed was short of next->cifp_x.
-	     * If y was not yet at next->cifp_y, add one more point
-	     * to bridge the gap.
-	     */
-	    if (y != next->cifp_y)
-	    {
-		new = (CIFPath *) mallocMagic((unsigned) (sizeof (CIFPath)));
-		new->cifp_x = xlast;
-		new->cifp_y = next->cifp_y;
-		new->cifp_next = next;
-		path->cifp_next = new;
-		path = new;
-	    }
-	}
-    }
-}
-
-#endif /* NONMANHATTAN */
-
 
 /*
  * ----------------------------------------------------------------------------
@@ -1743,9 +1580,7 @@ CIFReadFile(file)
 
     cifTotalWarnings = 0;
     cifTotalErrors = 0;
-#ifdef NONMANHATTAN
     CifPolygonCount = 0;
-#endif
 
     cifInputFile = file;
     cifReadScale1 = 1;
