@@ -17,7 +17,7 @@
  *     *********************************************************************
  *
  *
- * rcsid "$Header: /usr/cvsroot/magic-8.0/cif/cif.h,v 1.3 2010/05/04 20:14:13 tim Exp $
+ * rcsid "$Header: /usr/cvsroot/magic-8.0/cif/cif.h,v 1.4 2010/06/24 12:37:15 tim Exp $
  */
 
 #ifndef _CIF_H
@@ -41,10 +41,8 @@ extern char *CIFPathPrefix;
 extern char *CIFErrorFilename;
 extern bool CIFArrayWriteDisable;
 extern bool CIFHierWriteDisable;
-#ifdef NONMANHATTAN
 extern bool CIFSubcellPolygons;
 extern bool CIFUnfracture;
-#endif
 
 /* Procedures that parse the cif sections of a technology file. */
 
