@@ -238,9 +238,10 @@ EFGetLengthAndWidth(dev, lptr, wptr)
  * For each dev in the circuit, call the user-supplied procedure
  * (*devProc)(), which should be of the following form:
  *
- *	(*devProc)(dev, hierName, trans, l, w, cdata)
+ *	(*devProc)(dev, hierName, scale, cdata)
  *	    Dev *dev;
  *	    HierName *hierName;
+ *	    float scale;
  *	    Transform *trans;
  *	    ClientData cdata;
  *	{
@@ -301,33 +302,16 @@ efVisitDevs(hc, ca)
     if (efHierSrUses(hc, efVisitDevs, (ClientData) ca))
 	return 1;
 
-    /*
-     * Compute the proper transform to convert distance values to
-     * scaled distances.  This transform will have a scale different
-     * from 1 only in the case when the scale factors of some of the
-     * .ext files differed, making it necessary to scale all dimensions
-     * explicitly instead of having a single scale factor applying to
-     * the entire circuit.
-     */
-    scale = def->def_scale;
+    scale = (efScaleChanged && def->def_scale != 1.0) ? def->def_scale : 1.0;
     t = hc->hc_trans;
-    if (efScaleChanged && scale != 1.0)
-    {
-	t.t_a = (int)((float)t.t_a * scale);
-	t.t_b = (int)((float)t.t_b * scale);
-	t.t_c = (int)((float)t.t_c * scale);
-	t.t_d = (int)((float)t.t_d * scale);
-	t.t_e = (int)((float)t.t_e * scale);
-	t.t_f = (int)((float)t.t_f * scale);
-    }
-
+  
     /* Visit our own devices */
     for (dev = def->def_devs; dev; dev = dev->dev_next)
     {
 	if (efDevKilled(dev, hc->hc_hierName))
 	    continue;
 
-	if ((*ca->ca_proc)(dev, hc->hc_hierName, &t, ca->ca_cdata))
+	if ((*ca->ca_proc)(dev, hc->hc_hierName, scale, &t, ca->ca_cdata))
 	    return 1;
     }
 
@@ -513,8 +497,6 @@ efVisitResists(hc, ca)
 {
     Def *def = hc->hc_use->use_def;
     Connection *res;
-    Transform t;
-    int scale;
 
     /* Ignore subcircuits */
     if (def->def_flags & DEF_SUBCIRCUIT) return 0;
@@ -576,7 +558,7 @@ efVisitSingleResist(hc, name1, name2, res, ca)
 	return 0;
 
     if ((he = EFHNLook(hc->hc_hierName, name2, "resist(2)")) == NULL)
-	return;
+	return 0; 
     n2 = ((EFNodeName *) HashGetValue(he))->efnn_node;
     if (n2->efnode_flags & EF_KILLED)
 	return 0;
@@ -864,7 +846,7 @@ EFHNOut(hierName, outf)
     HierName *hierName;
     FILE *outf;
 {
-    bool trimGlob, trimLocal;
+    bool trimGlob, trimLocal, trimComma;
     char *cp, c;
 
     if (hierName->hn_parent) efHNOutPrefix(hierName->hn_parent, outf);
@@ -873,9 +855,16 @@ EFHNOut(hierName, outf)
 	cp = hierName->hn_name; 
 	trimGlob = (EFTrimFlags & EF_TRIMGLOB);
 	trimLocal = (EFTrimFlags & EF_TRIMLOCAL);
+	trimComma = (EFTrimFlags & EF_CONVERTCOMMAS);
 	while (c = *cp++)
 	{
-	    if (*cp) (void) putc(c, outf);
+	    if (*cp) 
+	    {
+		if (trimComma && (c == ','))
+		    putc(';', outf);
+		else
+		    putc(c, outf);
+	    }
 	    else switch (c)
 	    {
 		case '!':	if (!trimGlob) (void) putc(c, outf); break;
