@@ -111,6 +111,18 @@ typedef struct LB1
 
 LinkedBoundary **extSpecialBounds;		/* Linked Boundary List */
 
+/* Structure used for finding substrate connections on implicitly-defined
+ * substrates
+ */
+
+typedef struct TSD1
+{
+    bool found;		/* Set to 1 if a substrate connection was found */
+    Rect rtrans;	/* Rectangle of device */
+    Rect rhalo;		/* Search halo around device */
+    NodeRegion *nreg;	/* Closest substrate region within halo */
+} TransSubsData;
+
 #define	EDGENULL(r)	((r)->r_xbot > (r)->r_xtop || (r)->r_ybot > (r)->r_ytop)
 
 /* Forward declarations */
@@ -118,7 +130,7 @@ void extOutputNodes();
 int extTransTileFunc();
 int extTransPerimFunc();
 NodeRegion *extTransFindSubsNode();
-int extTransFindSubsFunc();
+int extTransFindSubs();
 
 int extAnnularTileFunc();
 int extResistorTileFunc();
@@ -198,7 +210,7 @@ extBasic(def, outFile)
 
     /* Assign the labels to their associated regions */
     if (!SigInterruptPending)
-	ExtLabelRegions(def, ExtCurStyle->exts_nodeConn);
+	ExtLabelRegions(def, ExtCurStyle->exts_nodeConn, &nodeList);
 
     /*
      * Make sure all geometry with the same label is part of the
@@ -394,9 +406,24 @@ extOutputNodes(nodeList, outFile)
 	fprintf(outFile, "node \"%s\" %d %lg", text, intR, finC);
 
 	/* Output its location (lower-leftmost point and type name) */
-	fprintf(outFile, " %d %d %s",
+
+	if (reg->nreg_type & TT_DIAGONAL) {
+	    /* Node may be recorded as a diagonal tile if no other	*/
+	    /* non-diagonal tiles are adjoining it.			*/
+
+	    TileType loctype = (reg->nreg_type & TT_SIDE) ? ((reg->nreg_type &
+			TT_RIGHTMASK) >> 14) : (reg->nreg_type & TT_LEFTMASK);
+
+	    fprintf(outFile, " %d %d %s",
+		    reg->nreg_ll.p_x, reg->nreg_ll.p_y,
+		    DBTypeShortName(loctype));
+	}
+	else
+	{
+	    fprintf(outFile, " %d %d %s",
 		    reg->nreg_ll.p_x, reg->nreg_ll.p_y,
 		    DBTypeShortName(reg->nreg_type));
+	}
 
 	/* Output its area and perimeter for each resistivity class */
 	for (n = 0; n < ExtCurStyle->exts_numResistClasses; n++)
@@ -1137,7 +1164,13 @@ extOutputParameters(def, transList, outFile)
 	    {
 		fprintf(outFile, "parameters %s", ExtCurStyle->exts_transName[t]);
 		for (; plist != NULL; plist = plist->pl_next)
-		    fprintf(outFile, " %c=%s", plist->pl_param, plist->pl_name);
+		{
+		    if (plist->pl_scale != 1.0)
+			fprintf(outFile, " %c=%s*%g", plist->pl_param,
+					plist->pl_name, plist->pl_scale);
+		    else
+			fprintf(outFile, " %c=%s", plist->pl_param, plist->pl_name);
+		}
 		fprintf(outFile, "\n");
 	    }
 	}
@@ -1473,12 +1506,20 @@ extOutputTrans(def, transList, outFile)
 	    case DEV_RSUBCKT:
 		hasModel = strcmp(ExtCurStyle->exts_transName[t], "None");
 		length = extTransRec.tr_perim;
+		isAnnular = FALSE;
 	
 		/* Boundary perimeter scan for resistors with more than */
 		/* one tile.						*/
 
-		for (n = 0; n < extTransRec.tr_nterm &&
-				extTransRec.tr_termnode[n] != NULL; n++);
+		for (n = 0; n < extTransRec.tr_nterm; n++)
+		{
+		    if (extTransRec.tr_termnode[n] == NULL) continue;
+
+		    /* Mark annular resistors as requiring extra processing */
+		    if (extTransRec.tr_termvector[n].p_x == 0 &&
+				extTransRec.tr_termvector[n].p_y == 0)
+			isAnnular = TRUE;
+		}
 
 		if (n == 0)
 		    width = length = 0;
@@ -1495,14 +1536,21 @@ extOutputTrans(def, transList, outFile)
 
 		    arg.fra_uninit = (ClientData) extTransRec.tr_gatenode;
 		    arg.fra_region = (Region *) reg;
-		    arg.fra_each = extResistorTileFunc;
+		    if (isAnnular)
+		        arg.fra_each = extAnnularTileFunc;
+		    else
+		        arg.fra_each = extResistorTileFunc;
 		    (void) ExtFindNeighbors(reg->treg_tile, arg.fra_pNum, &arg);
 
 		    if (extSpecialBounds[0] != NULL)
 		    {
 			extSeparateBounds(n - 1);
-			extComputeEffectiveLW(&width, &length, n, 
-				ExtCurStyle->exts_cornerChop[t]);
+			if (isAnnular)
+			    extComputeEffectiveLW(&length, &width, n, 
+					ExtCurStyle->exts_cornerChop[t]);
+			else
+			    extComputeEffectiveLW(&width, &length, n, 
+					ExtCurStyle->exts_cornerChop[t]);
 		    }
 		    else
 		    {
@@ -1738,7 +1786,7 @@ extOutputTrans(def, transList, outFile)
 }
 
 int
-extTransFindSubsFunc1(tile, def, sn)
+extTransFindSubs(tile, def, sn)
     Tile *tile;
     CellDef *def;
     NodeRegion **sn;
@@ -1747,7 +1795,7 @@ extTransFindSubsFunc1(tile, def, sn)
     TileTypeBitMask *mask;
     Rect tileArea;
     int pNum;
-    int extTransFindSubsFunc2();	/* Forward declaration */
+    int extTransFindSubsFunc1();	/* Forward declaration */
 
     TiToRect(tile, &tileArea);
     if (IsSplit(tile))
@@ -1760,7 +1808,7 @@ extTransFindSubsFunc1(tile, def, sn)
 	if (TTMaskIntersect(&DBPlaneTypes[pNum], mask))
 	{
 	    if (DBSrPaintArea((Tile *) NULL, def->cd_planes[pNum], &tileArea,
-		    mask, extTransFindSubsFunc2, (ClientData)sn))
+		    mask, extTransFindSubsFunc1, (ClientData)sn))
 		return 1;
 	}
     }
@@ -1768,18 +1816,26 @@ extTransFindSubsFunc1(tile, def, sn)
 }
 
 int
-extTransFindSubsFunc2(tile, sn)
+extTransFindSubsFunc1(tile, sn)
     Tile *tile;
     NodeRegion **sn;
 {
+    /* Report split substrate region errors (two different substrate
+     * regions under the same device)
+     */
+
     if (tile->ti_client != (ClientData) extUnInit)
     {
+	if ((*sn != (NodeRegion *)NULL) && (*sn != tile->ti_client))
+	    TxError("Warning:  Split substrate under device at (%d %d)\n",
+			tile->ti_ll.p_x, tile->ti_ll.p_y);
+
 	*sn = (NodeRegion *) tile->ti_client;
 	return 1;
     }
     return 0;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1848,7 +1904,8 @@ extTransTileFunc(tile, pNum, arg)
     extTransRec.tr_perim += perim;
 
     if (extTransRec.tr_subsnode == (NodeRegion *)NULL)
-	extTransFindSubsFunc1(tile, arg->fra_def, &extTransRec.tr_subsnode);
+	extTransFindSubs(tile, arg->fra_def, &extTransRec.tr_subsnode);
+
     return (0);
 }
 
